@@ -12,7 +12,8 @@ MainWidget::MainWidget(QWidget *parent) :
     QWidget(parent),
     m_mediaObject_tor(new Phonon::MediaObject(this)),
     m_mediaObject_pfeife(new Phonon::MediaObject(this)),
-    m_audioOutput(new Phonon::AudioOutput(Phonon::MusicCategory, this)),
+    m_audioOutput_tor(new Phonon::AudioOutput(Phonon::MusicCategory, this)),
+    m_audioOutput_pfeife(new Phonon::AudioOutput(Phonon::MusicCategory, this)),
     m_backend(new BackendKicker(this)),
     m_datamodel(new MatchDayModel(this, m_backend)),
     m_scoretbl(new ScoreTable(m_datamodel)),
@@ -57,11 +58,11 @@ MainWidget::MainWidget(QWidget *parent) :
     connect(m_backend, SIGNAL(matchAdded(Match*)),
            this, SLOT(onMatchAdded(Match*)));
 
-    m_mediaObject_tor->setCurrentSource(Phonon::MediaSource("/usr/share/buliscores/tor.wav"));
-    m_mediaObject_pfeife->setCurrentSource(Phonon::MediaSource("/usr/share/buliscores/trillerpfeife.wav"));
+    m_mediaObject_tor->setCurrentSource(Phonon::MediaSource("/usr/share/buliscores/tor.mp3"));
+    m_mediaObject_pfeife->setCurrentSource(Phonon::MediaSource("/usr/share/buliscores/trillerpfeife.mp3"));
 
-    Phonon::createPath(m_mediaObject_tor,     m_audioOutput);
-    Phonon::createPath(m_mediaObject_pfeife,  m_audioOutput);
+    Phonon::createPath(m_mediaObject_tor,     m_audioOutput_tor);
+    Phonon::createPath(m_mediaObject_pfeife,  m_audioOutput_pfeife);
 }
 
 void MainWidget::mousePressEvent(QMouseEvent* event)
@@ -72,11 +73,20 @@ void MainWidget::mousePressEvent(QMouseEvent* event)
     if (event->button() == Qt::RightButton) {
         this->showSettingsDialog();
     } else {
-//        qDebug() << "current volume: " << m_audioOutput->volumeDecibel();
-//        qDebug() << "MO state: " << m_mediaObject_pfeife->state();
-//        m_mediaObject_pfeife->seek(0);
-//        m_mediaObject_pfeife->play();
-//        qDebug() << "MO state 2: " << m_mediaObject_pfeife->state();
+        qDebug() << "pfeife volume: " << m_audioOutput_pfeife->volume();
+        qDebug() << "tor volume: " << m_audioOutput_tor->volume();
+        qDebug() << "pfeife state: " << m_mediaObject_pfeife->state();
+        qDebug() << "tor state: " << m_mediaObject_pfeife->state();
+        m_mediaObject_pfeife->seek(0);
+        if (m_settings.value("Sounds", false).toBool()) {
+            m_mediaObject_pfeife->play();
+        }
+        m_mediaObject_tor->seek(0);
+        if (m_settings.value("Sounds", false).toBool()) {
+            m_mediaObject_tor->play();
+        }
+        qDebug() << "pfeife state 2: " << m_mediaObject_pfeife->state();
+        qDebug() << "tor state 2: " << m_mediaObject_pfeife->state();
     }
 }
 
@@ -106,6 +116,7 @@ void MainWidget::onMatchAdded(Match* match) {
 
     connect(match, SIGNAL(stateChanged(Match::MatchState)),
             this, SLOT(onMatchStateChanged(Match::MatchState)));
+
     qDebug() << "Match (" << match->homeTeam() << " vs "
              << match->awayTeam() << ") : registering signals";
 }
