@@ -13,19 +13,19 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     ui->setupUi(this);
 
     league = settings.value("League", "1. Bundesliga").toString();
-
-    if (league == "1. Bundesliga") {
+    if (league == ui->rbBL1->text()) {
         ui->rbBL1->setChecked(true);
-    } else if (league == "2. Bundesliga") {
+    } else if (league == ui->rbBL2->text()) {
         ui->rbBL2->setChecked(true);
-    } else if (league == "tipp3 Bundesliga") {
+    } else if (league == ui->rbT3BL->text()) {
         ui->rbT3BL->setChecked(true);
     } else {
         ui->rbBL1->setChecked(true);
     }
 
-    connect(ui->buttonGroup, SIGNAL(buttonClicked(QAbstractButton*)),
-            this, SLOT(onLeagueSelected(QAbstractButton*)));
+    ui->cbPlaySound->setChecked(settings.value("Sounds", false).toBool());
+
+    connect(ui->buttonBox, SIGNAL(accepted()), this, SLOT(onDlgAccepted()));
 }
 
 SettingsDialog::~SettingsDialog()
@@ -33,8 +33,9 @@ SettingsDialog::~SettingsDialog()
     delete ui;
 }
 
-void SettingsDialog::onLeagueSelected(QAbstractButton* button)
+void SettingsDialog::onDlgAccepted()
 {
-    settings.setValue("League", button->text());
+    settings.setValue("League", ui->buttonGroup->checkedButton()->text());
+    settings.setValue("Sounds", ui->cbPlaySound->isChecked());
     this->accept();
 }
